pub struct DirectCommands {
pub dst_addr: u8,
pub src_addr: u8,
pub payload: CommandPayload,
}Expand description
Represents a Direct Commands packet (frame type 0x32).
Fields
dst_addr: u8src_addr: u8payload: CommandPayloadTrait Implementations
Sourceimpl Clone for DirectCommands
impl Clone for DirectCommands
Sourcefn clone(&self) -> DirectCommands
fn clone(&self) -> DirectCommands
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CrsfPacket for DirectCommands
impl CrsfPacket for DirectCommands
Sourceconst PACKET_TYPE: PacketType = PacketType::Command
const PACKET_TYPE: PacketType = PacketType::Command
The CRSF frame type identifier for this packet.
Sourceconst MIN_PAYLOAD_SIZE: usize = 4usize
const MIN_PAYLOAD_SIZE: usize = 4usize
The minimum expected length of the packet’s payload in bytes.
For fixed-size packets, this is the same as the payload size.
Sourcefn from_bytes(data: &[u8]) -> Result<Self, CrsfParsingError>
fn from_bytes(data: &[u8]) -> Result<Self, CrsfParsingError>
Creates a packet instance from a payload byte slice.
The slice is guaranteed to have a length of at least
MIN_PAYLOAD_SIZE.fn to_bytes(&self, buffer: &mut [u8]) -> Result<usize, CrsfParsingError>
fn validate_buffer_size(&self, buffer: &[u8]) -> Result<(), CrsfParsingError>
Sourceimpl Debug for DirectCommands
impl Debug for DirectCommands
Sourceimpl PartialEq for DirectCommands
impl PartialEq for DirectCommands
impl StructuralPartialEq for DirectCommands